summaryrefslogtreecommitdiffstats
path: root/kchart/kchart_factory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kchart/kchart_factory.h')
-rw-r--r--kchart/kchart_factory.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kchart/kchart_factory.h b/kchart/kchart_factory.h
index a40c39e8..4e64c583 100644
--- a/kchart/kchart_factory.h
+++ b/kchart/kchart_factory.h
@@ -11,8 +11,8 @@
#include <KoFactory.h>
-class KInstance;
-class KAboutData;
+class TDEInstance;
+class TDEAboutData;
namespace KChart
{
@@ -32,14 +32,14 @@ public:
const char* classname = "KoDocument",
const TQStringList &args = TQStringList() );
- static KInstance* global();
+ static TDEInstance* global();
- // _Creates_ a KAboutData but doesn't keep ownership
- static KAboutData* aboutData();
+ // _Creates_ a TDEAboutData but doesn't keep ownership
+ static TDEAboutData* aboutData();
private:
- static KInstance* s_global;
- static KAboutData *s_aboutData;
+ static TDEInstance* s_global;
+ static TDEAboutData *s_aboutData;
};
} //namespace KChart